@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Planner;
-$ExtUtils::Builder::Planner::VERSION = '0.011';
+$ExtUtils::Builder::Planner::VERSION = '0.012';
 use strict;
 use warnings;
 
@@ -60,7 +60,7 @@ sub create_phony {
 	return $self->create_node(
 		target       => $target,
 		dependencies => \@dependencies,
-		phony        => 1,
+		type         => 'phony',
 	);
 }
 
@@ -158,7 +158,7 @@ ExtUtils::Builder::Planner - An ExtUtils::Builder Plan builder
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -196,9 +196,9 @@ The list of dependencies for this node.
 
 The actions to perform to create or update this node.
 
-=item * phony
+=item * type
 
-A boolean to mark a target as phony. This defaults to false.
+This marks the type of the node: C<file> or C<phony>, defaulting to the former.
 
 =back
 
